lightrayrider package
=====================

Submodules
----------

lightrayrider.parallel module
-----------------------------

.. automodule:: lightrayrider.parallel
   :members:
   :undoc-members:
   :show-inheritance:

lightrayrider.raytrace module
-----------------------------

.. automodule:: lightrayrider.raytrace
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: lightrayrider
   :members:
   :undoc-members:
   :show-inheritance:
